RtcNotificationEventContent

Struct RtcNotificationEventContent 

#[non_exhaustive]
pub struct RtcNotificationEventContent { pub sender_ts: MilliSecondsSinceUnixEpoch, pub lifetime: Duration, pub mentions: Option<Mentions>, pub relates_to: Option<Reference>, pub notification_type: NotificationType, pub call_intent: Option<CallIntent>, }
The content of an m.rtc.notification event.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
sender_ts: MilliSecondsSinceUnixEpoch

Local timestamp observed by the sender device.

Used with lifetime to determine validity; receivers SHOULD compare with origin_server_ts and prefer it if the difference is large.

lifetime: Duration

Relative time from sender_ts during which the notification is considered valid.

mentions: Option<Mentions>

Intentional mentions determining who should be notified.

relates_to: Option<Reference>

Optional reference to the related m.rtc.member event.

notification_type: NotificationType

How this notification should notify the receiver.

call_intent: Option<CallIntent>

Gives a soft indication of whether the call is a “audio” or “video” (+audio) call.

This is just to indicate between trusted callers that they can start with audio or video off, but the actual call semantics remain the same, and they may switch at will.

Implementations

Source

impl RtcNotificationEventContent

pub fn new( sender_ts: MilliSecondsSinceUnixEpoch, lifetime: Duration, notification_type: NotificationType, ) -> Self

Creates a new RtcNotificationEventContent with the given configuration.

pub fn expiration_ts( &self, origin_server_ts: MilliSecondsSinceUnixEpoch, max_sender_ts_offset: Option<u32>, ) -> MilliSecondsSinceUnixEpoch

Calculates the timestamp at which this notification is considered invalid. This calculation is based on MSC4075 and tries to use the sender_ts as the starting point and the lifetime as the duration for which the notification is valid.

The sender_ts cannot be trusted since it is a generated value by the sending client. To mitigate issue because of misconfigured client clocks, the MSC requires that the origin_server_ts is used as the starting point if the difference is large.

Arguments:
  • max_sender_ts_offset is the maximum allowed offset between the two timestamps. (default 20s)
  • origin_server_ts has to be set to the origin_server_ts from the event containing this event content.
Examples

To start a timer until this client should stop ringing for this notification: let duration_ring = MilliSecondsSinceUnixEpoch::now().saturated_sub(content.expiration_ts(event. origin_server_ts(), None));